===============================
cellulist
===============================

.. image:: https://img.shields.io/travis/eddiejessup/cellulist.svg
        :target: https://travis-ci.org/eddiejessup/cellulist

.. image:: https://img.shields.io/pypi/v/cellulist.svg
        :target: https://pypi.python.org/pypi/cellulist


Periodic cell list

* Free software: BSD license
* Documentation: https://cellulist.readthedocs.org.

Features
--------

* TODO
